@@ -163,7 +163,7 @@ The package was greatly inspired by U{Lee Feigenbaum's similar package for Javas
 @requires: U{RDFLib<http://rdflib.net>} package.
 """
 
-__version__ = "1.7.6"
+__version__ = "1.8.0"
 """The version of SPARQLWrapper"""
 
 __authors__  = "Ivan Herman, Sergio Fernández, Carlos Tejo Alonso, Alexey Zakhlestin"
@@ -185,7 +185,7 @@ __agent__   = "sparqlwrapper %s (rdflib.github.io/sparqlwrapper)" % __version__
 
 
 from .Wrapper import SPARQLWrapper
-from .Wrapper import XML, JSON, TURTLE, N3, JSONLD, RDF
+from .Wrapper import XML, JSON, TURTLE, N3, JSONLD, RDF, RDFXML
 from .Wrapper import GET, POST
 from .Wrapper import SELECT, CONSTRUCT, ASK, DESCRIBE, INSERT, DELETE
 from .Wrapper import URLENCODED, POSTDIRECTLY
